@@ -1,20 +1,20 @@
 /*
  * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
- * 
+ *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
  *     the Free Software Foundation; either version 2 of the License, or
  *     (at your option) any later version.
- * 
+ *
  *     This program is distributed in the hope that it will be useful,
  *     but WITHOUT ANY WARRANTY; without even the implied warranty of
  *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *     GNU General Public License for more details.
- * 
+ *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
  *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */ 
+ */
 
 #include "attach.h"
 
@@ -42,8 +42,7 @@ typedef struct
   HEADER *hdr;	/* current message */
   BODY *bdy;	/* current attachment */
   FILE *fp;	/* source stream */
-  ATTACHPTR **idx;	/* attachment information */
-  short idxlen;
+  ATTACH_CONTEXT *actx;	/* attachment information */
 } pager_t;
 
 int mutt_do_pager (const char *, const char *, int, pager_t *);
